xarxa

Crates

git

Versions

default

Flavors

DhcpLease

Struct DhcpLease 

pub struct DhcpLease {
    pub server: DhcpServerInfo,
    pub address: Ipv4Cidr,
    pub router: Option<Ipv4Address>,
    pub dns_servers: Vec<Ipv4Address, DHCP_MAX_DNS_SERVER_COUNT>,
    pub options: DhcpLeaseOptions,
}
A lease obtained from a DHCP server.

Fields

server: DhcpServerInfo

How to reach the server that gave the lease.

address: Ipv4Cidr

The leased address and its subnet.

router: Option<Ipv4Address>

The default gateway, if the server gave one.

dns_servers: Vec<Ipv4Address, DHCP_MAX_DNS_SERVER_COUNT>

The DNS servers, if the server gave any.

options: DhcpLeaseOptions

All options received from the DHCP server.

You may have to ask the server to send the option you’re interested in with DhcpConfig::parameter_request_list.